aboutsummaryrefslogtreecommitdiff
path: root/js/reveal.js
diff options
context:
space:
mode:
authorHakim El Hattab <hakim.elhattab@gmail.com>2012-10-13 12:04:33 -0400
committerHakim El Hattab <hakim.elhattab@gmail.com>2012-10-13 12:04:33 -0400
commit421b78aafb2e2c00af4d771c988347964675ef42 (patch)
treec1cca7c043834355ccd7fa18de27d42f593359ce /js/reveal.js
parented1db1f3c871c1bf85085973c49b361ab420bf46 (diff)
downloadfosdem-2018-presentation-421b78aafb2e2c00af4d771c988347964675ef42.tar
fosdem-2018-presentation-421b78aafb2e2c00af4d771c988347964675ef42.tar.gz
ability to define autoSlide duration per slide
Diffstat (limited to 'js/reveal.js')
-rw-r--r--js/reveal.js14
1 files changed, 7 insertions, 7 deletions
diff --git a/js/reveal.js b/js/reveal.js
index 56f5578..aaad7c3 100644
--- a/js/reveal.js
+++ b/js/reveal.js
@@ -1,5 +1,5 @@
/*!
- * reveal.js 2.1 r31
+ * reveal.js 2.1 r32
* http://lab.hakim.se/reveal-js
* MIT licensed
*
@@ -34,7 +34,7 @@ var Reveal = (function(){
// Number of milliseconds between automatically proceeding to the
// next slide, disabled when set to 0, this value can be overwritten
// by using a data-autoSlide attribute on your slides
autoSlide: 0,
// Enable slide navigation via mouse wheel
@@ -53,7 +53,7 @@ var Reveal = (function(){
dependencies: []
},
- // stores if the next slide should be shown automatically
+ // Stores if the next slide should be shown automatically
// after n milliseconds
autoSlide = config.autoSlide,
@@ -845,11 +845,11 @@ var Reveal = (function(){
state = state.concat( slideState.split( ' ' ) );
}
- // if this slide has a autoSlide attribtue associated use this as autoSlide value
- // otherwise use the global configured time
- var slideAutoSlide = slides[index].getAttribute( 'data-autoslide' );
+ // If this slide has a data-duration attribtue associated use this as
+ // autoSlide value otherwise use the global configured time
+ var slideAutoSlide = slides[index].getAttribute( 'data-duration' );
if( slideAutoSlide ) {
- autoSlide = parseInt(slideAutoSlide);
+ autoSlide = parseInt( slideAutoSlide );
} else {
autoSlide = config.autoSlide
}
@@ -34,7 +34,7 @@ var Reveal = (function(){
// Number of milliseconds between automatically proceeding to the
// next slide, disabled when set to 0, this value can be overwritten
- // by using a data-autoSlide attribute on your slides
+ // by using a data-duration attribute on your slides
autoSlide: 0,
// Enable slide navigation via mouse wheel